@@ -30,7 +30,10 @@ class Index:
                    :meth:`~sheraf.attributes.Attribute.search` method is
                    used.
     :param mapping: The mapping object to be used to store the indexed values.
-                   By default :class:`~BTrees.OOBTree.OOBTree` is used.
+                   By default the `index_mapping` class attribute is used.
+                   If you know that the keys of the index will always be a
+                   specific type, like integers, you might way to use this
+                   attribute to use specialized datastructures.
     :param nullok: If `True`, `None` or empty values can be indexed. `True` by default.
     :param noneok: Ignored in if `nullok` is `True`. Else, if `noneok` is
                    `True`, `None` values can be indexed. `False` by default."
@@ -71,6 +74,8 @@ class Index:
     UniqueIndexException
     """
 
+    default_mapping = OOBTree
+
     def __init__(
         self,
         *attributes,
@@ -89,7 +94,7 @@ class Index:
         self.default_values_func = values
         self.search_func = search or values
         self.values_funcs = {}
-        self.mapping = mapping or OOBTree
+        self.mapping = mapping or self.default_mapping
         self.primary = primary
         self.nullok = nullok
         self.noneok = noneok
@@ -135,6 +140,9 @@ class Index:
         ...     m = Cowboy.create(first_name="George", last_name="Abitbol", surname="Georgy")
         ...     assert m in Cowboy.filter(theindex="george abitbol")
         ...     assert m in Cowboy.filter(theindex="georgy")
+
+        .. note :: You can use :meth:`~sheraf.models.indexation.BaseIndexedModel.index_keys`
+                   to check the index keys your custom function generates.
         """
 
         # Guess if the decorator has been called with or without parenthesis
@@ -181,6 +189,9 @@ class Index:
         ...     m = Model.create(foo="foo", bar="bar")
         ...     assert m in Model.search(theindex="foo")
         ...     assert m in Model.search(theindex="BAR")
+
+        .. note :: You can use :meth:`~sheraf.models.indexation.BaseIndexedModel.search_keys`
+                   to check the index keys your custom function generates.
         """
 
         def wrapper(func):
