@@ -420,8 +420,10 @@ class InlineModelAttribute(ModelLoader, Attribute):
     'Jolly Jumper'
     """
 
+    default_mapping = sheraf.types.SmallDict
+
     def __init__(self, model=None, **kwargs):
-        kwargs.setdefault("default", sheraf.types.SmallDict)
+        kwargs.setdefault("default", self.default_mapping)
         super().__init__(model=model, **kwargs)
 
     def deserialize(self, value):
@@ -486,11 +488,13 @@ class IndexedModelAttribute(ModelLoader, Attribute):
     ...     assert jolly in george.horses.search(size=32)
     """
 
+    index_table_default = sheraf.types.SmallDict
+
     def read(self, parent):
         for index in self.model.indexes.values():
             key = self.key(parent)
             if key not in parent.mapping:
-                parent.mapping[key] = sheraf.types.SmallDict()
+                parent.mapping[key] = self.index_table_default()
             index.persistent = parent.mapping[key]
 
         return self.model
