@@ -1,11 +1,13 @@
 import itertools
 
-import sheraf.types
 from BTrees.OOBTree import OOBTree
+from ..types import SmallDict
+from sheraf.databases import Database
+from sheraf.exceptions import NotConnectedException, UniqueIndexException
 
 
 class IndexManager:
-    root_default = sheraf.types.SmallDict
+    root_default = SmallDict
     index_multiple_default = OOBTree
 
     def __init__(self, details, index_multiple_default=None):
@@ -38,7 +40,7 @@ class IndexManager:
     def get_item(self, key, silent_errors=False):
         items = self._get_item(key, silent_errors)
 
-        if not isinstance(items, OOBTree):
+        if not isinstance(items, self.index_multiple_default):
             # TODO: deprecate this and delete it sometimes
             return items
 
@@ -111,7 +113,7 @@ class IndexManager:
 
         for value in values:
             if value in self.table():
-                raise sheraf.exceptions.UniqueIndexException(
+                raise UniqueIndexException(
                     "The key '{}' is already present in the index '{}'".format(
                         value, self.details.key
                     )
@@ -121,7 +123,7 @@ class IndexManager:
         del table[index_key]
 
     def _table_del_multiple(self, table, index_key, value, primary_key):
-        if isinstance(table[index_key], OOBTree):
+        if isinstance(table[index_key], self.index_multiple_default):
             del table[index_key][primary_key]
             if len(table[index_key]) == 0:
                 del table[index_key]
@@ -136,7 +138,7 @@ class IndexManager:
 
     def _table_set_multiple(self, table, index_key, value, primary_key):
         index_container = table.setdefault(index_key, self.index_multiple_default())
-        if isinstance(index_container, OOBTree):
+        if isinstance(index_container, self.index_multiple_default):
             index_container[primary_key] = value
         else:
             # TODO: deprecate this and delete it sometimes
@@ -193,9 +195,9 @@ class SimpleIndexManager(IndexManager):
 
 
 def current_database_name():
-    current_name = sheraf.Database.current_name()
+    current_name = Database.current_name()
     if not current_name:
-        raise sheraf.exceptions.NotConnectedException()
+        raise NotConnectedException()
     return current_name
 
 
@@ -207,7 +209,7 @@ class MultipleDatabaseIndexManager(IndexManager):
 
     def database_root(self, database_name=None):
         database_name = database_name or self.database_name or current_database_name()
-        return sheraf.Database.current_connection(database_name).root()
+        return Database.current_connection(database_name).root()
 
     def root(self, database_name=None, setdefault=True):
         root = self.database_root(database_name)
