@@ -1,9 +1,7 @@
 import itertools
 import operator
 from collections import OrderedDict
-from collections.abc import Iterable
-
-from BTrees.OOBTree import OOTreeSet, union, intersection, difference
+from collections.abc import Iterable, Iterator
 
 import sheraf.constants
 from sheraf.exceptions import InvalidFilterException, InvalidOrderException
@@ -136,13 +134,16 @@ class QuerySet(object):
         return super().__eq__(other)
 
     def __and__(self, other):
-        return QuerySet(intersection(OOTreeSet(self), OOTreeSet(other)))
+        return QuerySet(set(self) & set(other))
 
     def __or__(self, other):
-        return QuerySet(union(OOTreeSet(self), OOTreeSet(other)))
+        return QuerySet(set(self) | set(other))
 
     def __xor__(self, other):
-        return QuerySet(difference(OOTreeSet(self), OOTreeSet(other)))
+        return QuerySet(set(self) ^ set(other))
+
+    def __add__(self, other):
+        return QuerySet(unique_everseen(itertools.chain(self, other)))
 
     def __bool__(self):
         try:
@@ -205,12 +206,7 @@ class QuerySet(object):
     @property
     def indexed_filters(self):
         return [
-            (
-                name,
-                value,
-                search_func,
-                self.orders.get(name) == sheraf.constants.DESC,
-            )
+            (name, value, search_func, self.orders.get(name) == sheraf.constants.DESC,)
             for (name, value, search_func) in self.filters.values()
             if name in self.model.indexes
         ]
@@ -345,7 +341,12 @@ class QuerySet(object):
         ...     # now qcopy is consumed
         """
 
-        qs = QuerySet(self._iterable, self.model)
+        if isinstance(self._iterable, Iterator):
+            self._iterable, iterable = itertools.tee(self._iterable)
+        else:
+            iterable = self._iterable
+
+        qs = QuerySet(iterable, self.model)
         qs.filters = self.filters.copy()
         qs.orders = self.orders.copy()
         qs._predicate = self._predicate
